<?php
# Copyright (C) 2011 Matthew Wronka <murder@projects.matt.wronka.org>
# 
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, version 3 of the
# License.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
# 
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>

class BasicUser
{
	// from /etc/passwd
	protected $login;

	protected $self    = array(); // from file

	protected $lastModified = 0;

	protected function updateLastModifiedByFile($file)
	{
		$stat = stat($file);
		if($stat)
		{
			if($modified = safeGet($stat, 'mtime'))
			{
				if($modified > $this->lastModified)
				{
					$this->lastModified = $modified;
				}
			}
		}
	}

	public function getLastModified() { return $this->lastModified; }

	protected function __construct($nick, $data)
	{
		$this->login = $nick;
		$this->loadSelf($data);
	}

	protected function loadSelf($data)
	{
		foreach($data as $l)
		{
			$l = trim($l);
			if($l && substr($l,0,1) != '#')
			{
				list($k,$v) = explode("\t", $l, 2);
				//$this->self[$k] = explode("\t", $v);
				$this->self[$k] = trim($v);
			}
		}
	}

	// At the moment this is pretty straight forward.
	// We may want to add some sort of checks to ensure
	// We have information to make this relevant
	// We could also cache users depending on access patterns
	static public function fetch($file)
	{
		if(!is_readable($file)) return false;
		$data = file($file);
		if(!$data || !is_array($data)) return false;
		$user = new BasicUser(basename($file), $data);
		if($user)
		{
			return $user;
		}
		return false;
	}

	public function getLogin() { return $this->login; }
	public function getRoom() { return false; }
	public function getHomePhone() { return false; }
	public function getWorkPhone() { return false; }
	public function getOther() { return false; }
	public function getPlan() { return false; }
	public function getProject() { return false; }
	public function getKnownPeople() { return false; }

	protected function getFromSelf($key) { return getFirst(safeGet($this->self, $key)); }

	////////////////// The following use getFromSelf() ////////////////////
	public function getName()
	{
		return $this->getFromSelf('name');
	}

	public function getNickname()
	{
		$nick = $this->getFromSelf('nick');
		if($nick) return $nick;
		return $this->getLogin();
	}

	public function getOpenID()
	{
		return $this->getFromSelf('openid');
	}

	public function getHonorificPrefix()
	{
		return $this->getFromSelf('title');
	}

	public function getNameGiven()
	{
		return $this->getFromSelf('givenname');
	}

	public function getNameFamily()
	{
		return $this->getFromSelf('surname');
	}

	public function getGender()
	{
		return $this->getFromSelf('gender');
	}

	public function getMyersBriggs()
	{
		return $this->getFromSelf('myersbriggs');
	}

	public function getGeekCode()
	{
		return $this->getFromSelf('geekcode');
	}

	public function getBirthday()
	{
		$a = explodea(' ', $this->getFromSelf('born'), 2);
		return $a[0];
	}

	public function getJabberID()
	{
		return $this->getFromSelf('jabber');
	}

	public function getEMail()
	{
		return $this->getFromSelf('email');
	}

	public function getSIP()
	{
		return $this->getFromSelf('sip');
	}

	public function getChatAIM()
	{
		return $this->getFromSelf('aim');
	}
	public function getChatMSN()
	{
		return $this->getFromSelf('msn');
	}
	public function getChatICQ()
	{
		return $this->getFromSelf('icq');
	}
	public function getChatYahoo()
	{
		return $this->getFromSelf('yahoo');
	}
	public function getSkype()
	{
		return $this->getFromSelf('skype');
	}

	public function getWeblog()
	{
		return $this->getFromSelf('weblog');
	}

	public function getWishlist()
	{
		return $this->getFromSelf('tipjar');
	}

	public function getBirthdayAnniversary()
	{
		$birthday = $this->getBirthday();
		if(!$birthday) return false;
		$n = strpos($birthday, '-', 1);
		if($n > 0) return substr($birthday, $n+1);
		return false;
	}

	public function getDepictionURI()
	{
		return $this->getFromSelf('img');
	}

	public function getThumbnailURI()
	{
		return $this->getFromSelf('thumb');
	}

	public function getOtherFOAF()
	{
		return $this->getFromSelf('foaf');
	}

	public function getOnelineBio()
	{
		return $this->getFromSelf('olb');
	}

	public function getHomepage()
	{
		return $this->getFromSelf('homepage');
	}
}
