<?php
# Copyright (C) 2011 Matthew Wronka <murder@projects.matt.wronka.org>
# 
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, version 3 of the
# License.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
# 
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>

require_once('php/system/basicuser.inc');
class LocalUser extends BasicUser
{
	// from /etc/passwd
	protected $login;
	protected $name;
	protected $room;
	protected $workPhone;
	protected $homePhone;
	protected $other;
	protected $uid;
	protected $home;
	protected $shell;
	protected $hidden;	// .nofinger

	protected $project = false;
	protected $plan    = false;
	protected $pgpkey  = false;

	protected $hasImage= false;
	protected $hasThumb= false;
	protected $known   = false;

	protected $config  = false;

	public function __construct($line)
	{
		$fields = explode(':', $line);
		$comments	= explode(',',$fields[4]);
		$this->name	= safeGet($comments,0);
		$this->room	= safeGet($comments,1);
		$this->workPhone= $this->_formatPhone(safeGet($comments,2));
		$this->homePhone= $this->_formatPhone(safeGet($comments,3));
		$this->other	= safeGet($comments,4);
		$this->login	= $fields[0];
		$this->uid	= $fields[2];
		$this->home	= $fields[5];
		$this->shell	= $fields[6];

		if($this->name == '&')
		{
			$this->name = ucwords($this->login);
		}

		$nofinger = $this->home . '/' . config('PUBLIC_BASE') . '/' . config('USER_NOFINGER');
		$this->hidden = file_exists($nofinger);
		if($this->hidden) $this->updateLastModifiedByFile($nofinger);
		if(!class_exists('PersonalImageRenderer', false))
		{
			$this->hasImage= false;
			$this->hasThumb= false;
		} else {
			$imageFile = $this->getImageFile(false);
			$thumbFile = $this->getImageFile(true );
			$this->hasImage = file_exists($imageFile);
			$this->hasThumb = file_exists($thumbFile);
			if($this->hasImage) $this->updateLastModifiedByFile($imageFile);
			if($this->hasThumb) $this->updateLastModifiedByFile($thumbFile);
		}

		// load over-rides
		$selfFile = $this->home .'/'. config('PUBLIC_BASE') . '/' . config('USER_BASE') . '/me' ;
		if(file_exists($selfFile))
		{
			$lines = file($selfFile);
			$this->loadSelf($lines);
			$this->updateLastModifiedByFile($selfFile);
		}
	}

	private function _formatPhone($f)
	{
		if(!$f) return;
		return "$f";	// todo.  logic.
	}

	public function isHidden() { return $this->hidden; }
	public function getName() { return $this->name; }
	public function getHome() { return $this->home; }
	public function getUID() { return $this->uid; }
	public function getShell() { return $this->shell; }
	public function getRoom() { return $this->room; }
	public function getWorkPhone() { return $this->workPhone; }
	public function getHomePhone() { return $this->homePhone; }
	public function getOther() { return $this->other; }

	public function uri() { return baseUrl() . '/~' . $this->login . '/'; }

	public function getPlan()
	{
		if($this->plan === false)
		{
			$f =$this->home .'/'. config('PUBLIC_BASE') . '/' . config('USER_PLAN');
			if(is_readable($f))
			{
				$this->plan = file_get_contents($f);
				$this->updateLastModifiedByFile($f);
			} else $this->plan = '';
		}
		return $this->plan;
	}

	public function getProject()
	{
		if($this->project === false)
		{
			$f =$this->home .'/'. config('PUBLIC_BASE') . '/' . config('USER_PROJECT');
			if(is_readable($f))
			{
				$this->project = file_get_contents($f);
				$this->updateLastModifiedByFile($f);
			} else $this->project = '';
		}
		return $this->project;
	}

	public function getPGPKey()
	{
		if($this->pgpkey === false)
		{
			$f =$this->home .'/'. config('PUBLIC_BASE') . '/' . config('USER_PGPKEY');
			if(is_readable($f))
			{
				$this->pgpkey = file_get_contents($f);
				$this->updateLastModifiedByFile($f);
			} else $this->pgpkey = '';
		}
		return $this->pgpkey;
	}

	public function hasWeb()
	{
		return is_readable($this->home.'/'. config('WEB_DIR'));
	}

	public function hasImage() { return $this->hasImage; }
	public function hasThumb() { return $this->hasThumb; }

	protected function getFilePath($fileName)
	{
		return $this->home .'/'. config('PUBLIC_BASE') . '/' . config('USER_BASE') . '/' . $fileName;
	}

	public function getFileAsArray($userFile)
	{
		$f = $this->getFilePath($userFile);
		if(!(file_exists($f) && is_file($f) )) return array();
		$r = array();
		foreach(file($f) as $l)
		{
			$r[] = trim($l);
		}
		return $r;
	}

	public function getConfigValue($key)
	{
		if($this->config === false)
		{
			$this->config = array();
			$conf = $this->getFileAsArray('config');
			foreach($conf as $line)
			{
				list($k, $v) = xsplit('=', $line, 2);
				$this->config[trim($k)] = trim($v);
			}
		}
		return safeGet($this->config, $key);
	}

	public function getImageFile($thumb=false)
	{
		$lfile = ($thumb?config('USER_THUMB'):config('USER_IMAGE'));
		return $this->getFilePath($lfile);
	}

	private function getImageURI($thumb=false)
	{
		if($thumb) return $this->uri() . 'img/thumb';
		else return $this->uri() . 'img/';
	}

	public function getDepictionURI()
	{
		$dep = parent::getDepictionURI();
		if($dep) return $dep;
		if($this->hasImage()) return $this->getImageURI(false);
		return false;
	}

	public function getThumbnailURI()
	{
		$thumb = parent::getThumbnailURI();
		if($thumb) return $thumb;
		if($this->hasThumb()) return $this->getImageURI(true);
		return false;
	}

	//////////////////// The following are from .murder/knows ///////////////////
	private function _loadKnows()
	{
		if($this->known !== false) return;
		$this->known = array();
		$knownDir = $this->home .'/'. config('PUBLIC_BASE') . '/' . config('USER_BASE') . '/knows/' ;
		if(!is_dir($knownDir) || !is_readable($knownDir)) return;
		$files = scandir($knownDir);
		foreach($files as $f)
		{
			if(substr($f,0,1) == '.') continue;
			$user = BasicUser::fetch($knownDir . $f);
			if($user) $this->known[$f] = $user;
			$this->updateLastModifiedByFile($knownDir . $f);
		}
	}

	public function getKnownPeople()
	{
		if($this->known === false)
		{
			$this->_loadKnows();
		}
		return $this->known;
	}

	///////////////////// The following are from .murder/me ////////////////////
	public function getEMail()
	{
		$email = parent::getEMail();
		if($email) return $email;
		if($domain = config('MAIL_DOMAIN'))
		{
			return $this->getLogin() . '@' . $domain;
		}
	}

	public function getJabberID()
	{
		$xmpp = parent::getJabberID();
		if($xmpp) return $xmpp;
		if($domain = config('XMPP_DOMAIN'))
		{
			return $this->getLogin() . '@' . $domain;
		}
		return false;
	}

	public function getHomepage()
	{
		$homepage = parent::getHomepage();
		if($homepage) return $homepage;
		if(!$this->hasWeb()) return false;
		if(!class_exists('WebRenderer', false)) return;
		return $this->uri() . 'web/';
	}
}

?>
