<?php
# Copyright (C) 2011 Matthew Wronka <murder@projects.matt.wronka.org>
# 
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, version 3 of the
# License.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
# 
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>

require_once(dirname(__FILE__) . '/util.inc');
require_once(dirname(__FILE__) . '/message.inc');

class MailBoardRenderer extends ComponentRenderer
{
	private $user;
	private $bIsGood;
	private $contentType;
	private $posts;

	public function __construct($page, $arguments, $contentType)
	{
		parent::__construct($page, $arguments, $contentType);
		$feeds = false;
		$this->user = $page->getUser();
		if($this->user)
		{
			$support = MailBoardRendererUtil::getSupportFile($this->user);
			$posts = false;
			if($support)
			{
				$incfile = dirname(__FILE__) . '/' . $support .'.inc';
				if(file_exists($incfile))
				{
					include_once($incfile);
					$posts = MailBoardReader::read($this->user);
					$this->updateLastModified($posts, $page);	
				}
			}
		}

		$this->posts = $posts;
		if( $this->bIsGood = ($posts?true:false) )
		{ 
		}
	}

	protected function updateLastModified($posts, $page)
	{
		if(sizeof($posts) && $page)
		{
			foreach($posts as $p)
			{
				$page->setLastModified($p->getTime());
			}
		}
	}

	public function startComponent($name)
	{
		parent::startComponent($name);
		if($this->bIsGood) print "<h3>Board</h3>";
	}

	public function mainContent($page)
	{
		if(!$this->bIsGood)
		{
			return;
		}
		$posts = $this->posts;
		if(sizeof($posts))
		{
			$replyAddr = htmlspecialchars(MailBoardRendererUtil::getPostAddress($this->user));
			$threads = MailBoardRendererUtil::groupAndOrderMessages($posts);
			print '<dl>';
			foreach($threads as $subject => $posts)
			{
				if(!$subject) continue;
				$psubj  = htmlspecialchars(urlencode($subject));
				$subject= htmlspecialchars($subject);
				$params = "subject=${psubj}";
				if($replyAddr)
				{
					$reply  = "<a href='mailto:${replyAddr}?${params}'>Reply</a>";
				}
				else $reply = '';
				print "<di><dt>${subject} ${reply}</dt>\n";
				foreach($posts as $post)
				{
					$author = htmlspecialchars($post->getAuthor());
					$body   = nl2br(htmlspecialchars($post->getBody()));
					$date   = $post->getDate();
					
					print "<dd><strong>${author}</strong> <b>${date}</b><br />${body}</dd>\n";
				}
				print "</di>";
			}
			print '</dl>';
			if($replyAddr)
			{
				$postLink = "<a href='mailto:${replyAddr}'>Send Message</a>";
				print "<p>${postLink}</p>";
			}
		}
	}

	public function sendHeaders($page)
	{
		if($this->bIsGood) 
		{
			if($this->contentType)
			{
				$page->setContentType($this->contentType);
			} else {
				$page->setContentType('application/xhtml+xml');
			}
		}
		parent::sendHeaders($page);
	}
}

registerp(array('text/xml' => "MailBoardRenderer"), "board");
registerp(array('application/xhtml+xml' => "MailBoardRenderer"), "board");
registerp(array('*/*' => "MailBoardRenderer"), "board");
registerc('BOARD', 'MailBoardRenderer', "board");

?>
