<?php
# Copyright (C) 2011 Matthew Wronka <murder@projects.matt.wronka.org>
# 
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, version 3 of the
# License.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
# 
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>

class MailBoardRendererUtil
{
	public static function getMailbox($user)
	{
		$home= $user->getHome();
		$box = $user->getConfigValue('board');
		if(!$home || !$box) return false;
		return $home .'/' . $box;
	}

	public static function getPostAddress($user)
	{
		$home= $user->getHome();
		$addr= $user->getConfigValue('board_mail');
		if(!$addr)
		{
			$addr = $user->getEMail();
		}
		return $addr;
	}

	public static function groupMessages($posts)
	{
		$rval = array();
		foreach($posts as $p)
		{
			$subject = $p->getSubject();
			if(!isset($rval[$subject]))
			{
				$rval[$subject] = array();
			}
			$rval[$subject][] = $p; 
		}
		return $rval;
	}

	public static function compareMessagesR($a, $b)
	{
		return (-1 * MailBoardRendererUtil::compareMessages($a, $b));
	}

	public static function compareMessages($a, $b)
	{
		if(!$a && !$b) return 0;
		if(!$a) return  1;
		if(!$b) return -1;
		$d1 = $a->getDate();
		$d2 = $b->getDate();
		if($d1 == $d2) return 0;
		if(!$d1) return  1;
		if(!$d2) return -1;
		return ($d1 < $d2 ? -1 : 1);
	}

	public static function compareThreads($a, $b)
	{
		if(!$a && !$b) return 0;
		if(!$a) return  1;
		if(!$b) return -1;
		$t1 = safeGet($a,0);
		$t2 = safeGet($b,0);
		if($t1 == $t2) return 0;
		if(!$t1) return  1;
		if(!$t2) return -1;
		return  MailBoardRendererUtil::compareMessagesR($t1, $t2);
	}

	public static function groupAndOrderMessages($posts)
	{
		$rval = array();
		$threads = MailBoardRendererUtil::groupMessages($posts);
		while(list($subject, $messages) = each($threads))
		{
			usort($messages, 'MailBoardRendererUtil::compareMessagesR');
			$rval[$subject] = $messages;

		}
		uasort($rval, 'MailBoardRendererUtil::compareThreads');
		return $rval;
	}

	public static function getSupportFile($user)
	{
		$mailbox = MailBoardRendererUtil::getMailbox($user);
		if(!$mailbox) return false;
		if(!file_exists($mailbox)) return;
		if(is_dir($mailbox)) return 'maildir';
		return false;
	}

	# unescapes quoted-printable
	public static function unquote($s)
	{
		$len = strlen($s);
		$m = 0;
		$r = '';
		while(false !== ($n = strpos($s, '=', $m)) )
		{
			if($n)
			{
				$r .= substr($s, $m, $n-$m);
			}
			if($m+2>$len) break;
			$x = substr($s, $n+1, 2);
			$d = hexdec($x);
			$k = $d?chr($d):false;
			if($k && mb_check_encoding($k, "UTF-8"))
			{
				 $r .= $k;
			}
			else
			{
				$r .= '='.$x;
			}
			$m = $n+3;
		}
		$r .= substr($s, $m);
		return $r;
	}
} 

?>
