<?php
# Copyright (C) 2011 Matthew Wronka <murder@projects.matt.wronka.org>
# 
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, version 3 of the
# License.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
# 
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>

class PersonalImageRenderer extends PageRenderer
{
	private $fspath;
	private $bIsGood;

	public function __construct($page, $arguments, $contentType)
	{
		parent::__construct($page, $arguments);
		$user = $page->getUser();

		$bWantsImage = (!$arguments || !sizeof($arguments));
		$bWantsThumb = (!$bWantsImage && (sizeof($arguments)==1) && $arguments[0] == 'thumb');

		if(!$user || $user->isHidden()) 
		{
			$this->bIsGood = false;
		}
		else if($bWantsImage  && $user->hasImage())
		{
			$this->bIsGood = true; 
			$this->fspath = ($user->getImageFile(false));
		}
		else if($bWantsThumb && $user->hasThumb())
		{
			$this->bIsGood = true; 
			$this->fspath = ($user->getImageFile(true));
		}
		else { $this->bIsGood = false; }
	}

	public function mainContent($page)
	{
		if(!$this->bIsGood)
		{
			print "<p>Image unavailable.</p>";
			return;
		}
		readfile($this->fspath);
	}

	public function sendHeaders($page)
	{
		if($this->bIsGood) 
		{
			$mt = murder_mime_content_type($this->fspath);
			$page->setContentType($mt);
			$stat = stat($this->fspath);
			if($modified = safeGet($stat, 'mtime'))
			{
				$page->setLastModified($modified);
			}
		}
		parent::sendHeaders($page);
	}

	public function startPage($page)
	{
		if(!$this->bIsGood) parent::startPage($page);
	}

	public function endPage($page)
	{
		if(!$this->bIsGood) parent::endPage($page);
	}
}

registerp(array('image/*' => "PersonalImageRenderer"), "/");
registerp(array('image/*' => "PersonalImageRenderer"), "img");
registerp(array('*/*' => "PersonalImageRenderer"), "img");

?>
