<?php
# Copyright (C) 2011 Matthew Wronka <murder@projects.matt.wronka.org>
# 
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, version 3 of the
# License.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
# 
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>

class PGPKeyRenderer extends PageRenderer
{
	private $user;
	private $bIsGood;
	private $contentType;

	public function __construct($page, $arguments, $contentType)
	{
		parent::__construct($page, $arguments);
		$this->user = $page->getUser();
		$this->contentType = $contentType;
		if(!$this->user || $this->user->isHidden() || !$this->user->getPGPKey()) 
		{
			$this->bIsGood = false;
		}
		else
		{
			$this->bIsGood = true; 
		}
	}

	public function mainContent($page)
	{
		if(!$this->bIsGood)
		{
			print "<p>No PGP key available.</p>";
			return;
		}
		print $this->user->getPGPKey();
	}

	public function sendHeaders($page)
	{
		if($this->bIsGood) 
		{
			if($this->contentType)
			{
				$page->setContentType($this->contentType);
			} else {
				$page->setContentType('application/pgp-keys');
			}
		}
		parent::sendHeaders($page);
	}

	public function startPage($page)
	{
		if(!$this->bIsGood) parent::startPage($page);
	}

	public function endPage($page)
	{
		if(!$this->bIsGood) parent::endPage($page);
	}
}

registerp(array('application/pgp-keys' => "PGPKeyRenderer"), "/");
registerp(array('application/pgp-keys' => "PGPKeyRenderer"), "pgp.key");
registerp(array('text/plain' => "PGPKeyRenderer"), "pgp.key");
registerp(array('*/*' => "PGPKeyRenderer"), "pgp.key");

?>
