<?php
# Copyright (C) 2011 Matthew Wronka <murder@projects.matt.wronka.org>
# 
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, version 3 of the
# License.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
# 
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>

require_once(dirname(__FILE__) . '/simplepie.inc');

class SimplePieRenderer extends ComponentRenderer
{
	private $user;
	private $bIsGood;
	private $contentType;
	private $simplePie;

	public function __construct($page, $arguments, $contentType)
	{
		parent::__construct($page, $arguments, $contentType);
		$feeds = false;
		$this->user = $page->getUser();
		if($this->user)
		{
			$feeds = $this->user->getFileAsArray('feeds');
		}
		if( $this->bIsGood = ($feeds?true:false) )
		{ 
			$cacheDir = config('MURDER_DIR') . 'simplepie/';
			ensureDir($cacheDir, 0777, true);
			$this->contentType = $contentType;
			$this->simplePie = new SimplePie($feeds, $cacheDir);
			$this->simplePie->set_useragent('Murder SimplePie');
			$this->simplePie->set_timeout(10);
			$this->simplePie->force_feed();
			$items = $this->simplePie->get_items();
			if(sizeof($items))
			{
				// update last modified
				foreach($items as $item)
				{
					$date=intval($item->get_date('U'));
					if($date > 0)
					{
						$page->setLastModified($date);
					}
				}
			}
			else
			{
				$this->bIsGood = false;	// nothing to show
			}
		}
	}

	public function startComponent($name)
	{
		parent::startComponent($name);
		if($name == 'NEWS')
		{
			if($this->bIsGood) print "<h3>News Feed</h3>";
		}
	}

	public function componentContent($page, $name)
	{
		if(!$this->bIsGood)
		{
			return;
		}
		$items = $this->simplePie->get_items();
		if(sizeof($items))
		{
			if($name == 'NEWS') $this->renderNewsFeed($items);
			else if($name == 'PICS') $this->renderPicFeed($items);
		}
	}

	public function mainContent($page)
	{
		$this->componentContent($page, 'NEWS');
	}

	protected function renderNewsFeed($items)
	{
		print '<ol>';
		foreach($items as $item)
		{
			$enclosures = $item->get_enclosures();
			if($enclosures) continue;
			$link = $item->get_permalink();
			if(!$link || substr($link, 0, 4) != 'http')
			{
				$link = $item->get_feed()->get_link();
			}
			$title= $item->get_title();
			if($link)
				print "<li><a href=\"${link}\">${title}</a></li>\n";
			else print "<li>${title}</li>";
		}
		print '</ol>';
	}

	protected function renderPicFeed($items, $max = 12)
	{
		$displayed = 0;
		foreach($items as $item)
		{
			$enclosures = $item->get_enclosures();
			if(!$enclosures) continue;
			$link = $item->get_permalink();
			if(!$link || substr($link, 0, 4) != 'http')
			{
				$link = $item->get_feed()->get_link();
			}
			$title= $item->get_title();
			foreach($enclosures as $enc)
			{
				$mime = $enc->get_type();
				$l = htmlentities($enc->get_link(), 0, "UTF-8");
				$t = htmlspecialchars($title, 0, "UTF-8");
				$img = "<img src=\"${l}\" alt=\"${t}\" title=\"${t}\" />";
				if($link) $img = "<a href=\"${link}\">${img}</a>\n";
				print "${img}";
			}
			if(++$displayed >= $max) return;
		}
	}

	public function sendHeaders($page)
	{
		if($this->bIsGood) 
		{
			if($this->contentType)
			{
				$page->setContentType($this->contentType);
			} else {
				$page->setContentType('application/xhtml+xml');
			}
		}
		parent::sendHeaders($page);
	}
}

registerp(array('text/xml' => "SimplePieRenderer"), "news");
registerp(array('application/xhtml+xml' => "SimplePieRenderer"), "news");
registerp(array('*/*' => "SimplePieRenderer"), "news");
registerc('NEWS', 'SimplePieRenderer', "news");
registerc('PICS', 'SimplePieRenderer', "news");

?>
